=======
Credits
=======

Development Lead
----------------

* Dmitriy Sintsov <questpc256@gmail.com>

Contributors
------------

* ``pawelkoston``: Polish localization.
* ``Melvyn Sopacua``: Compatibility to 1.10+ new-style middleware; Dutch localization.
